@@ -1,3 +1,5 @@
+from belvo.investments.portfolios import InvestmentsPortfolios  # noqa
+from belvo.investments.transactions import InvestmentsTransactions  # noqa
 from belvo.resources.accounts import Accounts  # noqa
 from belvo.resources.balances import Balances  # noqa
 from belvo.resources.incomes import Incomes  # noqa
@@ -9,6 +11,7 @@ from belvo.resources.recurring_expenses import RecurringExpenses  # noqa
 from belvo.resources.risk_insights import RiskInsights  # noqa
 from belvo.resources.statements import Statements  # noqa
 from belvo.resources.tax_compliance_status import TaxComplianceStatus  # noqa
+from belvo.resources.tax_retentions import TaxRetentions  # noqa
 from belvo.resources.tax_returns import TaxReturns  # noqa
 from belvo.resources.tax_status import TaxStatus  # noqa
 from belvo.resources.transactions import Transactions  # noqa
